@@ -3,8 +3,10 @@ from vietvocoder.model.waveglow import WaveGlow
 from vietvocoder.model.denoiser import Denoiser
 
 class Predictor():
-    def __init__(self, waveglow_config, data_config, weight, device):
+    def __init__(self, config, weight, device):
         
+        data_config = config['data_config']
+        waveglow_config = config['waveglow_config']
         self.device = device
 
         self.model = WaveGlow(**waveglow_config)
