@@ -4,14 +4,17 @@ import soundfile
 import torch
 
 from vietvocoder.model.predictor import Predictor
-import vietvocoder.config as cfg
+from vietvocoder.utils.config import Cfg
 
 def predict(mel_file, model_weights, out_file, device):
     mel = np.load(mel_file)
+    
+    config = Cfg.load_config_from_name('waveglow')
+    sampling_rate = config['data_config']['sampling_rate']
 
-    predictor = Predictor(cfg.waveglow_config, cfg.data_config, model_weights, device)
+    predictor = Predictor(config, model_weights, device)
     audio = predictor.predict(mel)
-    soundfile.write(out_file, audio, cfg.data_config['sampling_rate'])
+    soundfile.write(out_file, audio, sampling_rate)
 
 if __name__=='__main__':
     parser = argparse.ArgumentParser()
