@@ -2,16 +2,19 @@ import argparse
 import torch
 
 from vietvocoder.model.trainer import Trainer
-import vietvocoder.config as cfg
+from vietvocoder.utils.config import Cfg
 
 def train(train_files, test_files, batch_size, device, resume):
+    
+    config = Cfg.load_config_from_name('waveglow')
 
-    trainer = Trainer(
-            cfg.data_config,
-            cfg.waveglow_config, 
-            {**cfg.train_config, 'train_files':train_files, 'test_files':test_files, 
-                    'batch_size':batch_size, 'device':device}
-            )
+    train_config = config['train_config']
+    train_config['train_files'] = train_files
+    train_config['test_files'] = test_files
+    train_config['batch_size'] = batch_size
+    train_config['device'] = device
+
+    trainer = Trainer(config)
     if resume:
         trainer.load_checkpoint()
 
